=======
xglider
=======


.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1297697.svg
   :target: https://doi.org/10.5281/zenodo.1297697

.. image:: https://img.shields.io/pypi/v/xglider.svg
   :target: https://pypi.python.org/pypi/xglider

.. image:: https://img.shields.io/travis/castelao/xglider.svg
   :target: https://travis-ci.org/castelao/xglider

.. image:: https://readthedocs.org/projects/xglider/badge/?version=latest
   :target: https://xglider.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://pyup.io/repos/github/castelao/xglider/shield.svg
   :target: https://pyup.io/repos/github/castelao/xglider/
   :alt: Updates



Generic tools to handle underwater gliders' data


* Free software: Apache Software License 2.0
* Documentation: https://xglider.readthedocs.io.


Features
--------

* TODO

Credits
-------
